% The program computes the spectrum and the impulse response of the modulated
% carrier knowing the phasor spectrum
clear all;
global NTS NSYM;
%
% FFT parameters
%
NTS=4096;
NSYM=1024;
NB=50;
NTL=4;
NTR=4;
freq=(-NTS/2:1/(2*NSYM):NTS/2-1/(2*NSYM)); % Normalized frequency axis. Normalization B=1/T
findex=(NTS*NSYM+1:NTS*NSYM+1+NB*2*NSYM);
fplot=freq(findex); % Unilateral frequency axis for plotting functions
bindex=(NTS*NSYM+1-NB*2*NSYM:NTS*NSYM+1+NB*2*NSYM);
bplot=freq(bindex); % Bilateral frequency axis for plotting functions
time=(-NSYM:1/NTS:NSYM-1/NTS); % Normalized time axis. Normalization T
tindex=(NTS*NSYM+1-NTL*NTS:NTS*NSYM+1+NTR*NTS); % Temporal axis for pulse representation. Pulse is identically zero outside tindex
tplot=time(tindex); % Dimensional temporal axis in ps for plotting output pulse (ps)
%
Phi=pi/2;
fB=1; % Normalized bandwidth
Mod_width=3; % Module width
Phase_asym=-1.5; % Position of the verticalphase asymptote
f0=20; % Carrier frequency
%
H_BB=zeros(1,2*NTS*NSYM);
H_BB(NTS*NSYM+1-2*NSYM*fB+1:2*NSYM*NTS)=sqrt(freq(NTS*NSYM+1-2*NSYM*fB+1:2*NSYM*NTS)+fB)./(1+exp((freq(NTS*NSYM+1-2*NSYM*fB+1:2*NSYM*NTS)/(Mod_width*fB))+1)).*...
    exp(1i*(fB./(freq(NTS*NSYM+1-2*NSYM*fB+1:2*NSYM*NTS)-Phase_asym*fB)-1)*Phi);
h_BB=PULSE(H_BB);
H_modR=circshift(H_BB,[0,2*NSYM*f0]);
H_modL=conj(circshift(fliplr(H_BB),[0,-2*NSYM*f0]));
H_mod=(H_modR+H_modL)/2;
h_mod=PULSE(H_mod);
%
% Graphics
%%
figure(1);
subplot(211);
plot(bplot,abs(H_BB(bindex)),'b',bplot,angle(H_BB(bindex))/pi,'b--',...
    bplot,abs(H_modR(bindex)),'r',bplot,angle(H_modR(bindex))/pi,'r--',...
    bplot,abs(H_modL(bindex)),'g',bplot,angle(H_modL(bindex))/pi,'g--',...
    bplot,abs(H_mod(bindex)),'k',bplot,angle(H_mod(bindex))/pi,'k--');
grid on;
xlabel('Normalized frequency');
ylabel('Amplitude and phase (\pi)');
title('Asymmetric bandpass phasor spectrum - Frequency response');
subplot(212);
plot(tplot,real(h_BB(tindex)),'b',tplot,imag(h_BB(tindex)),'r',...
    tplot,real(h_mod(tindex)),'k',tplot,imag(h_mod(tindex)),'k');
grid on;
xlabel('Normalized time');
ylabel('Real and imaginary parts');
title('Asymmetric bandpass phasor spectrum - Impulse response');
